summaryrefslogtreecommitdiff
path: root/orbsvcs/tests/Simple_Naming/run_test_ffp.pl
diff options
context:
space:
mode:
Diffstat (limited to 'orbsvcs/tests/Simple_Naming/run_test_ffp.pl')
-rwxr-xr-xorbsvcs/tests/Simple_Naming/run_test_ffp.pl4
1 files changed, 2 insertions, 2 deletions
diff --git a/orbsvcs/tests/Simple_Naming/run_test_ffp.pl b/orbsvcs/tests/Simple_Naming/run_test_ffp.pl
index 75d04a4e2fa..5ef2c750ed4 100755
--- a/orbsvcs/tests/Simple_Naming/run_test_ffp.pl
+++ b/orbsvcs/tests/Simple_Naming/run_test_ffp.pl
@@ -44,7 +44,7 @@ $test->DeleteFile($persistent_ior_file);
sub name_server
{
my $args = "-ORBNameServicePort $ns_multicast_port -o $test_iorfile -m 1 @_";
- my $prog = "../../Naming_Service/Naming_Service";
+ my $prog = "../../Naming_Service/tao_cosnaming";
$SV = $test->CreateProcess ("$prog", "$args");
@@ -125,7 +125,7 @@ foreach $o (@opts) {
$SV->Kill ();
## For some reason, only on Windows XP, we need to
## wait before starting another Naming_Service when
## the mmap persistence option is used
if ($^O eq "MSWin32") {
sleep(1);
@@ -125,7 +125,7 @@ foreach $o (@opts) {
$SV->Kill ();
## For some reason, only on Windows XP, we need to
- ## wait before starting another Naming_Service when
+ ## wait before starting another tao_cosnaming when
## the mmap persistence option is used
if ($^O eq "MSWin32") {